"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateDocs = exports.invokeApiExtractor = void 0;
const path = require("path");
const fs = require("fs");
const api_extractor_1 = require("@microsoft/api-extractor");
const change_case_1 = require("change-case");
function invokeApiExtractor(apiExtractorJsonPath, umdName) {
    const extractorConfig = api_extractor_1.ExtractorConfig.loadFileAndPrepare(apiExtractorJsonPath);
    const extractorResult = api_extractor_1.Extractor.invoke(extractorConfig, {
        // Equivalent to the "--local" command-line parameter
        localBuild: true,
        // Equivalent to the "--verbose" command-line parameter
        showVerboseMessages: true
    });
    if (!extractorResult.succeeded) {
        throw new Error(`API Extractor completed with ${extractorResult.errorCount} errors and ${extractorResult.warningCount} warnings`);
    }
    if (umdName) {
        fs.appendFileSync(extractorResult.extractorConfig.publicTrimmedFilePath, `\nexport as namespace ${(0, change_case_1.camelCase)(umdName)};\n`);
    }
}
exports.invokeApiExtractor = invokeApiExtractor;
async function generateDocs(root, outputDir) {
    const { MarkdownAction } = require('@microsoft/api-documenter/lib/cli/MarkdownAction.js');
    const markdownAction = new MarkdownAction();
    markdownAction._inputFolderParameter = { value: path.join(root, 'temp') };
    markdownAction._outputFolderParameter = { value: outputDir };
    await markdownAction.onExecute();
    fs.writeFileSync(path.resolve(root, outputDir, 'README.md'), fs.readFileSync(path.resolve(root, outputDir, 'index.md'), 'utf8'), 'utf8');
}
exports.generateDocs = generateDocs;
