"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.defineConfig = exports.watch = exports.build = void 0;
const path = require("path");
const fs = require("fs");
const tsapi = require("@tybys/tsapi");
const rollup_1 = require("./rollup");
const api_extractor_1 = require("./api-extractor");
/**
 * @public
 */
async function build(config) {
    var _a, _b;
    config.tscTargets.forEach(target => {
        var _a;
        tsapi.compile(path.resolve(config.root, (_a = config.baseTsconfig) !== null && _a !== void 0 ? _a : 'tsconfig.json'), target);
    });
    if ((_a = config.bundleTargets) === null || _a === void 0 ? void 0 : _a.length) {
        void (0, rollup_1.rollupBuild)(config.bundleTargets.map((target) => (0, rollup_1.getRollupConfig)(target, config)));
    }
    const apiExtractorJsonPath = path.resolve(config.root, 'api-extractor.json');
    if (fs.existsSync(apiExtractorJsonPath)) {
        (0, api_extractor_1.invokeApiExtractor)(apiExtractorJsonPath, config.libraryName);
        await (0, api_extractor_1.generateDocs)(config.root, (_b = config.docOutputPath) !== null && _b !== void 0 ? _b : 'docs/api');
    }
}
exports.build = build;
/**
 * @public
 */
function watch(config) {
    var _a;
    config.tscTargets.forEach(target => {
        var _a;
        tsapi.watch(path.resolve(config.root, (_a = config.baseTsconfig) !== null && _a !== void 0 ? _a : 'tsconfig.json'), target);
    });
    if ((_a = config.bundleTargets) === null || _a === void 0 ? void 0 : _a.length) {
        (0, rollup_1.rollupWatch)(config.bundleTargets.map((target) => (0, rollup_1.getRollupConfig)(target, config)));
    }
}
exports.watch = watch;
/**
 * @public
 */
function defineConfig(config) {
    return config;
}
exports.defineConfig = defineConfig;
