import { OutputOptions } from 'rollup';
import type { GlobalsOption, InputOptions, Plugin, RollupOutput } from 'rollup';
import type { RollupAliasOptions } from '@rollup/plugin-alias';
import type { MinifyOptions } from 'terser';
import type { Configuration } from './index';
/**
 * @public
 */
export interface BundleConfig {
    entry: string;
    output: {
        name: string;
        path: string;
    };
    /**
     * @defaultValue `false`
     */
    minify?: boolean;
    /**
     * @defaultValue `'umd'`
     */
    type?: 'umd' | 'esm-bundler' | 'commonjs' | 'mp' | 'esm';
    globals?: GlobalsOption;
    define?: Record<string, any>;
    resolveOnly?: ReadonlyArray<string | RegExp>;
    terserOptions?: MinifyOptions;
    plugins?: Plugin[];
    library?: string;
    preferBuiltins?: true;
    alias?: RollupAliasOptions;
    strict?: boolean;
}
export interface RollupConfig {
    input: InputOptions;
    output: OutputOptions;
}
export declare function getRollupConfig(target: BundleConfig, config: Configuration): RollupConfig;
export declare function rollupBuild(configs: RollupConfig[]): Promise<RollupOutput[]>;
export declare function rollupWatch(configs: RollupConfig[]): void;
