"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.rollupWatch = exports.rollupBuild = exports.getRollupConfig = void 0;
const path = require("path");
const rollup_1 = require("rollup");
const rollup_plugin_terser_1 = require("rollup-plugin-terser");
const plugin_node_resolve_1 = require("@rollup/plugin-node-resolve");
const plugin_alias_1 = require("@rollup/plugin-alias");
const change_case_1 = require("change-case");
const rollupJSON = require('@rollup/plugin-json');
const rollupCommonJS = require('@rollup/plugin-commonjs');
const rollupReplace = require('@rollup/plugin-replace');
const formats = {
    umd: (isProduction) => ({
        format: 'umd',
        ext: isProduction ? '.min.js' : '.js',
        define: {
            'process.env.NODE_ENV': isProduction ? JSON.stringify('production') : JSON.stringify('development'),
            __DEV__: !isProduction
        }
    }),
    'esm-bundler': (isProduction) => ({
        format: 'esm',
        ext: isProduction ? '.esm-bundler.min.js' : '.esm-bundler.js',
        define: {
            'process.env.NODE_ENV': '(process.env.NODE_ENV)',
            __DEV__: '(process.env.NODE_ENV !== "production")'
        }
    }),
    esm: (isProduction) => ({
        format: 'esm',
        ext: isProduction ? '.esm.min.js' : '.esm.js',
        define: {
            'process.env.NODE_ENV': isProduction ? JSON.stringify('production') : JSON.stringify('development'),
            __DEV__: !isProduction
        }
    }),
    commonjs: (isProduction) => ({
        format: 'commonjs',
        ext: isProduction ? '.cjs.min.js' : '.cjs.js',
        define: {
            'process.env.NODE_ENV': isProduction ? JSON.stringify('production') : JSON.stringify('development'),
            __DEV__: !isProduction
        }
    }),
    mp: (isProduction) => ({
        format: 'commonjs',
        ext: '.js',
        define: {
            'process.env.NODE_ENV': isProduction ? JSON.stringify('production') : JSON.stringify('development'),
            __DEV__: !isProduction
        }
    })
};
function getRollupConfig(target, config) {
    var _a, _b, _c, _d, _e, _f, _g, _h;
    const minify = (_a = target.minify) !== null && _a !== void 0 ? _a : false;
    const type = (_b = target.type) !== null && _b !== void 0 ? _b : 'umd';
    const rollupGlobals = (_c = target.globals) !== null && _c !== void 0 ? _c : {};
    const bundleDefine = (_d = target.define) !== null && _d !== void 0 ? _d : {};
    const f = formats[type];
    if (!f) {
        throw new Error('Not supported format: ' + type);
    }
    const formatConf = f(minify);
    // eslint-disable-next-line @typescript-eslint/prefer-nullish-coalescing
    const name = target.output.name || config.libraryName || '';
    const outputFilename = path.resolve(target.output.path, `${name}${formatConf.ext}`);
    const input = target.entry;
    const preferBuiltins = typeof target.preferBuiltins === 'boolean' ? target.preferBuiltins : true;
    const strict = typeof target.strict === 'boolean' ? target.strict : true;
    return {
        input: {
            input,
            plugins: [
                (0, plugin_node_resolve_1.default)({
                    preferBuiltins,
                    resolveOnly: [
                        ...((_e = target.resolveOnly) !== null && _e !== void 0 ? _e : [])
                    ],
                    mainFields: ['browser', 'module', 'main']
                }),
                rollupJSON(),
                rollupReplace({
                    preventAssignment: true,
                    ...(formatConf.define || {}),
                    ...bundleDefine
                }),
                ...(target.alias ? [(0, plugin_alias_1.default)(target.alias)] : []),
                rollupCommonJS({
                    transformMixedEsModules: true
                    // ignoreDynamicRequires: true,
                }),
                ...(minify
                    ? [(0, rollup_plugin_terser_1.terser)({
                            ...((_f = target.terserOptions) !== null && _f !== void 0 ? _f : {}),
                            module: (_h = ((_g = target.terserOptions) === null || _g === void 0 ? void 0 : _g.module)) !== null && _h !== void 0 ? _h : (['es', 'esm', 'module']).includes(formatConf.format)
                        })]
                    : []),
                ...(Array.isArray(target.plugins)
                    ? [
                        ...target.plugins
                    ]
                    : [])
            ]
        },
        output: {
            file: outputFilename,
            format: formatConf.format,
            // eslint-disable-next-line @typescript-eslint/prefer-nullish-coalescing
            name: target.library || (0, change_case_1.camelCase)(name),
            exports: 'named',
            globals: rollupGlobals,
            strict
        }
    };
}
exports.getRollupConfig = getRollupConfig;
async function rollupBuild(configs) {
    return await Promise.all(configs.map(conf => {
        return (0, rollup_1.rollup)(conf.input).then(bundle => bundle.write(conf.output));
    }));
}
exports.rollupBuild = rollupBuild;
function rollupWatch(configs) {
    (0, rollup_1.watch)(configs.map(conf => ({
        ...conf.input,
        output: conf.output,
        watch: {
            clearScreen: false
        }
    })));
}
exports.rollupWatch = rollupWatch;
